import { VueConstructor } from 'vue';

import AssociatePicker from './components/AssociatePicker.vue';
import ProjectPicker from './components/ProjectPicker.vue';
import { formatDate, truncate, dollars } from './filters';
import { CoolSelectPlugin } from 'vue-cool-select';
import PrettyRadio from 'pretty-checkbox-vue/radio';
import PrettyCheck from 'pretty-checkbox-vue/check';
import VueToast from 'vue-toast-notification';
import VueTimePicker from 'vue2-timepicker';
import Datepicker from 'vuejs-datepicker';
import VueLoadingButton from 'vue-loading-button';

// import 'node_modules/vue-cool-select/dist/themes/bootstrap.css';
// import './global.scss';

// Declare install function executed by Vue.use()
export function install(Vue: any) {
    if ((install as any).installed) {
        return;
    }
    (install as any).installed = true;
    // check to see if vue secure plugin is installed and throw an error if not
    // we need sharepointContext to work
    Vue.component('p-check', PrettyCheck);
    Vue.component('p-radio', PrettyRadio);
    Vue.use(CoolSelectPlugin);
    Vue.use(VueToast);
    Vue.component('vue-timepicker', VueTimePicker);
    Vue.component('Datepicker', Datepicker);
    Vue.component('AssociatePicker', AssociatePicker);
    Vue.component('ProjectPicker', ProjectPicker);
    Vue.component('VueLoadingButton', VueLoadingButton);
}

// Create module definition for Vue.use()
const plugin = {
    install,
};

// Auto-install when vue is found (eg. in browser via <script> tag)
let GlobalVue;
if (typeof window !== 'undefined') {
    GlobalVue = window.Vue;
} else if (typeof global !== 'undefined') {
    GlobalVue = global.Vue;
}
if (GlobalVue) {
    GlobalVue.use(plugin);
}

// (AssociatePicker as any).install = install;
// To allow use as module (npm/webpack/etc.) export component
export default plugin;

export { AssociatePicker };
export { ProjectPicker };
export { formatDate, truncate, dollars };
